@@ -1,4 +1,6 @@
+import json
 from .falcon import Event
+from .log import log
 
 
 class TranslatorError(Exception):
@@ -18,6 +20,7 @@ class FalconCache():
         self.falcon_api = falcon_api
         self._host_detail = {}
         self._mdm_id = {}
+        self._arc_config = {}
 
     def device_details(self, sensor_id):
         if not sensor_id:
@@ -35,6 +38,18 @@ class FalconCache():
 
         return self._host_detail[sensor_id]
 
+    def azure_arc_config(self, sensor_id):
+        if not sensor_id:
+            return EventDataError("Cannot fetch Azure Arc info. SensorId field is missing")
+        if sensor_id not in self._arc_config:
+            is_linux = self.device_details(sensor_id)['platform_name'] == 'Linux'
+            path = '/var/opt/azcmagent/agentconfig.json' if is_linux else 'C:\\ProgramData\\AzureConnectedMachineAgent\\Config\\agentconfig.json'
+            log.info('Fetching Azure Arc Config %s from the system %s', path, sensor_id)
+            file_bytes = self.falcon_api.rtr_fetch_file(sensor_id, path)
+            log.info('Fetched Azure Arc Config from the system: %s', str(file_bytes))
+            self._arc_config[sensor_id] = json.loads(file_bytes)
+        return self._arc_config[sensor_id]
+
     def mdm_identifier(self, sensor_id, event_platform):
         if not sensor_id:
             return EventDataError("Cannot process event. SensorId field is missing: ")
@@ -89,6 +104,9 @@ class FalconEvent():
         device_details = self.cache.device_details(self.original_event.sensor_id)
         return self.cache.mdm_identifier(self.original_event.sensor_id, device_details['platform_name'])
 
+    def azure_arc_config(self):
+        return self.cache.azure_arc_config(self.original_event.sensor_id)
+
     @property
     def cloud_provider(self):
         return self.device_details.get('service_provider', None)
@@ -132,3 +150,11 @@ class FalconEvent():
     @property
     def detect_name(self):
         return self.original_event['event']['DetectName']
+
+    @property
+    def service_name(self):
+        return self.original_event['event']['ServiceName']
+
+    @property
+    def audit_key_values(self):
+        return 'AuditKeyValues' in self.original_event['event']
